/**********************************************************************\
**
**                         Copyright (c) 2007-2017 by
**                          HENGSTLER GmbH, Aldingen
**
**      This  software  is furnished under a license and may be used and
**      copied only in accordance with the terms  of  such  license  and
**      with the inclusion of the above copyright notice.  This software
**      or any other copies thereof may not  be  provided  or  otherwise
**      made  available  to any other person.  No title to and ownership
**      of the software is hereby transferred.
**
**      The  information  in  this software is subject to change without
**      notice and should not be construed as a commitment by Hengstler.
**
**  Module:      Exo_Pmp_Interface.h
**  Facility:    S684015 - Hengstler Extendo Printer Driver for Windows XP/7/8/10
**  Component:   Print Monitor Plugin (Exo-PrintMonPlugin)
**  Version:     R7-V2.03-FINAL / 2017APR20
**  Environment: Microsoft Windows XP/7/8/10 
**  Compiler:    Microsoft Visual Studio 2015
**  Abstract:    Header file of module Exo_Pmp_PLUGIN.cpp
**  Note:        -
**  History:     R1-V1.00 / 2007DEC21 / HOR / 1ST RELEASE 
**               -----------------------------------------------------
**               R2-V1.01 / 2008MAY31 / HOR / 2ND RELEASE 
**               -----------------------------------------------------
**               R3-V1.02 / 2010APR30 / HOR / 3RD RELEASE
**               -----------------------------------------------------
**               R4-V2.00a / 2011MAY26 / HOR / M-R4-004-HOR
**                  Complete printer package ported to VS2010, reviewed and adapted Windows 7 32+64 bit
**               R4-V2.00 / 2013JUL18 / HOR / 4TH RELEASE
**               -----------------------------------------------------
**               R5-V2.01 / 2015MAY07 / HOR / 5TH RELEASE
**               -----------------------------------------------------
**               R6-V2.02b / 2016MAY25 / HOR / M-R6-007-HOR
**                  Driver package ported to VS2015 and adapted to Windows 10.
**               R6-V2.02 / 2016MAY25 / HOR / 6TH RELEASE
**               -----------------------------------------------------
**               R7-V2.03 / 2017APR20 / HOR / 7TH RELEASE
**               -----------------------------------------------------
**
\**********************************************************************/

#ifndef __EXO_PMP_INTERFACE_H 
#define __EXO_PMP_INTERFACE_H 

/*
** COMPILER
*/

/*
** INCLUDES
*/

#include "Exo_PrintMonPlugin.h"

/*
** MACROS 
*/

/*
** TYPES
*/

typedef struct
   { DWORD                dwSructId;         // Structure identification
     LPTSTR               pszPortName;       // Name of port (NULL indicates N/A)
     LPTSTR               pszPrinterName;    // Name of printer (NULL indicates N/A) for which monitoring is started
     LPTSTR               pszPrinterNameDoc; // Name of printer (NULL indicates N/A) for which document is printed
     TS_EXO_PMP_SETTINGS   sSettings;         // Plugin settings from registry
     HANDLE               hPmCallback;       // Handle of port monitor for read/write callbacks
     BOOL                 (*pfnWritePort) (HANDLE, LPBYTE, DWORD, LPDWORD, DWORD); 
                                             // Port monitor callback function for writing data to the port
     BOOL                 (*pfnReadPort)  (HANDLE, LPBYTE, DWORD, LPDWORD, DWORD);
                                             // Port monitor callback function for reading data from the port
     DWORD                dwJobId;           // ID of job currently processed (-1 indicates N/A)
   } S_EXO_PLUGIN_DATA, * P_EXO_PLUGIN_DATA;
#define P_EXO_PLUGIN_DATA_ID 0x056923FA
   

/*
** FUNCTIONS
*/

bool Exo_Pmp_Ifc_InquirePrinterData   (P_EXO_PLUGIN_DATA psData, BYTE ubId 
                                      ,LPBYTE pubRequest, DWORD dwRequest, LPBYTE pubResponse, DWORD dwResponse
                                      ,DWORD dwReadTimeoutMs);
bool Exo_Pmp_Ifc_WriteInfoToRegistry  (P_EXO_PLUGIN_DATA psData, PSTR pszValue, PBYTE pubInfo, DWORD dwSize);
bool Exo_Pmp_Ifc_ReadInfoFromRegistry (P_EXO_PLUGIN_DATA psData, PSTR pszValue, PBYTE pubInfo, DWORD dwSize);

/*
** VARIABLES
*/

#endif 
